@@ -48,9 +48,13 @@ DBusMessage *__connman_error_invalid_property(DBusMessage *msg);
 
 int __connman_selftest(void);
 
+#include <connman/types.h>
+
 int __connman_manager_init(DBusConnection *conn, gboolean compat);
 void __connman_manager_cleanup(void);
 
+connman_bool_t __connman_manager_get_offlinemode(void);
+
 int __connman_agent_init(DBusConnection *conn);
 void __connman_agent_cleanup(void);
 
@@ -124,12 +128,15 @@ int __connman_resolver_selftest(void);
 int __connman_storage_init(void);
 void __connman_storage_cleanup(void);
 
+GKeyFile *__connman_storage_open(void);
+void __connman_storage_close(GKeyFile *keyfile, gboolean save);
+
+int __connman_storage_load_global();
+int __connman_storage_save_global();
+
 int __connman_storage_init_device();
 int __connman_storage_load_device(struct connman_device *device);
 int __connman_storage_save_device(struct connman_device *device);
-int __connman_storage_init_network(struct connman_device *device);
-int __connman_storage_load_network(struct connman_network *network);
-int __connman_storage_save_network(struct connman_network *network);
 int __connman_storage_init_service();
 int __connman_storage_load_service(struct connman_service *service);
 int __connman_storage_save_service(struct connman_service *service);
@@ -197,6 +204,7 @@ int __connman_udev_init(void);
 void __connman_udev_cleanup(void);
 char *__connman_udev_get_devtype(const char *ifname);
 char *__connman_udev_get_mbm_devnode(const char *ifname);
+void __connman_udev_rfkill(const char *sysname, connman_bool_t blocked);
 
 #include <connman/device.h>
 
@@ -205,6 +213,13 @@ void __connman_device_cleanup(void);
 
 enum connman_service_type __connman_device_get_service_type(struct connman_device *device);
 
+int __connman_device_get_phyindex(struct connman_device *device);
+void __connman_device_set_phyindex(struct connman_device *device,
+							int phyindex);
+int __connman_device_set_blocked(struct connman_device *device,
+						connman_bool_t blocked);
+
+
 void __connman_device_increase_connections(struct connman_device *device);
 void __connman_device_decrease_connections(struct connman_device *device);
 
@@ -214,7 +229,9 @@ void __connman_device_cleanup_networks(struct connman_device *device);
 
 int __connman_device_scan(struct connman_device *device);
 int __connman_device_enable(struct connman_device *device);
+int __connman_device_enable_persistent(struct connman_device *device);
 int __connman_device_disable(struct connman_device *device);
+int __connman_device_disable_persistent(struct connman_device *device);
 int __connman_device_connect(struct connman_device *device);
 int __connman_device_disconnect(struct connman_device *device);
 
@@ -297,7 +314,7 @@ void __connman_notifier_enable(enum connman_service_type type);
 void __connman_notifier_disable(enum connman_service_type type);
 void __connman_notifier_connect(enum connman_service_type type);
 void __connman_notifier_disconnect(enum connman_service_type type);
-void __connman_notifier_offline_mode(connman_bool_t enabled);
+void __connman_notifier_offlinemode(connman_bool_t enabled);
 
 #include <connman/rtnl.h>
 
